""" Downloader for git.ir links """
import time
import argparse
from pathlib import Path

import requests
from tqdm import tqdm
from halo import Halo


ROOT_PATH = Path(__file__).resolve().parents[1]

links_path = ROOT_PATH / ".links.txt"


def download_files(folder_title, LINKS, args: argparse.Namespace):
    """
    Download files when the given URL is parsed
    """

    links_len = len(LINKS)

    if args.name:
        dir_path = ROOT_PATH / args.name
    else:
        dir_path = ROOT_PATH / folder_title

    # Create folder
    spinner = Halo(text="Creating folder", spinner="dots")
    spinner.start()

    dir_path.mkdir()
    spinner.stop_and_persist(symbol="✅".encode("utf-8"), text="Folder Created")

    print(f"Total files: {links_len}")

    # Start download
    for index, url in enumerate(LINKS):
        r = requests.get(url, stream=True, headers={"Accept-Encoding": None})
        total_size = int(r.headers.get("Content-Length"))

        spinner.text = f"Downloading {index + 1}/{links_len} file"
        spinner.spinner = "arrow3"
        spinner.start()
        time.sleep(1)
        spinner.stop()

        file = url.split("/")[-1]

        with open(dir_path / file, "wb") as f:
            with tqdm(
                total=total_size,
                desc=file,
                unit="B",
                unit_scale=True,
                bar_format="{l_bar}{bar:20}{r_bar}{bar:-10b}",
            ) as pbar:
                for chunk in r.iter_content(chunk_size=1024):
                    if chunk:
                        f.write(chunk)
                        pbar.update(len(chunk))

    spinner.spinner = "monkey"
    spinner.start()
    time.sleep(2)
    spinner.stop_and_persist(symbol="🔥".encode("utf-8"), text="All files downloaded.")



import os
import sys
import argparse

from .parser import parse_url
from .downloader import download_files


ROOT_DIR = os.path.dirname(os.path.abspath(__file__))


def init_argparse():
    """
    Initialize argparse module for commandline argument parsing.
    """
    parser = argparse.ArgumentParser(
        description="Downnload video files from git.ir links.",
        epilog="Enjoy the program :)",
    )

    parser.add_argument("link", type=str, help="git.ir URL")
    parser.add_argument(
        "-n", "--name", help="Folder name to store the downloaded files"
    )

    if len(sys.argv) == 1:
        parser.print_help()
        sys.exit(1)

    return parser.parse_args()


def start():
    """
    entrypoint for the app
    """
    try:
        args = init_argparse()

        folder_title, LINKS = parse_url(args)
        download_files(folder_title, LINKS, args)
    except KeyboardInterrupt:
        print("Stopped Downloading!" + " \N{cross mark}")
        try:
            sys.exit(0)
        except SystemExit:
            os._exit(0)



""" Parse URL and scrape relevant links. """
import re
import argparse
from typing import List

import requests
from bs4 import BeautifulSoup


def parse_url(args: argparse.Namespace) -> str:
    """
    Prase url and extract links
    """
    url = args.link

    try:
        page = requests.get(url)
    except requests.exceptions.RequestException as e:
        raise SystemExit(e)

    soup = BeautifulSoup(page.content, "html.parser")

    split_url = url.split("/")[-2:]
    folder_title: str = split_url[0]

    LINKS_STORE: List[str] = []

    for link in soup.findAll(
        "a", attrs={"href": re.compile("^https://cdn[0-9]+.git.ir/")}
    ):
        LINKS_STORE.append(link.get("href"))

    return folder_title, LINKS_STORE



import os
import argparse

import re
import argparse
from pathlib import Path

import requests
from tqdm import tqdm
from pyfiglet import Figlet
from bs4 import BeautifulSoup


ROOT_PATH = Path(__file__).resolve().parents[1]


links_path = ROOT_PATH/".links.txt"


def init_argparse():
    """
    Initialize argparse module for commandline argument parsing.
    """
    parser = argparse.ArgumentParser(description='Process git.ir links.', epilog = "Enjoy the program :)")

    # parser.add_argument('link', type = str, help = "git.ir URL")
    parser.add_argument('-n', '--name', help = "Folder name to store the downloaded files")
    parser.add_argument('-e', '--extract', help = "Used in case of a zipped file", default = True)

    return parser.parse_args()


def parse_url(args: argparse.Namespace) -> str:
    """
    Prase url and extract links
    """
    url = args.link

    try:
        page = requests.get(url)
    except requests.exceptions.RequestException as e:
        raise SystemExit(e)

    soup = BeautifulSoup(page.content, "html.parser")

    split_url = url.split("/")[-2:]
    folder_title = split_url[0]

    # if links_path.is_file():
    #     with open('.links.txt', 'r+') as f:
    #         if len(f.read()):
    #             f.truncate(0)
    # else:
    #     links_path.touch()

    LINKS_STORE = []

    for link in soup.findAll('a', attrs={'href': re.compile("^https://cdn[0-9]+.git.ir/")}):
        LINKS_STORE.append(link.get('href'))
        # with open(links_path, "a") as f:
        #     f.write(link.get('href') + '\n')

    return folder_title, LINKS_STORE


def download_files(args: str = ''):
    """
    Download files when the given URL is parsed
    """
    if args:
        name = args.name
    # name = folder_title

    # dir_path = ROOT_PATH/name

    os.system('echo Creating folder')
    # dir_path.mkdir()
    f = Figlet(font='slant')
    print(f.renderText('Downloading...'))
    # print(f"wget -i {links_path} -P {dir_path}/")

    url = 'https://cdn8.git.ir/1397/10/Packtpub%20Angular%20Full%20App%20with%20Angular%20Material%20Angularfire%20and%20NgRx%20%5BVideo%5D_git.ir.part3.rar'
    r = requests.get(url, stream = True)
    total_size = int(r.headers.get('content-length'))

    file = url.split('/')[-1]
    with open(file, 'wb') as f:
        with tqdm(total = total_size, desc = file, unit = "B", unit_scale = True,
                    bar_format='{l_bar: 20.0}{bar:10}{r_bar}{bar:-10b}') as pbar:
            for chunk in r.iter_content(chunk_size = 1024):
                if chunk:
                    f.write(chunk)
                    pbar.update(len(chunk))


def start():
    """
    entrypoint for the app
    """
    args = init_argparse()

    # folder_title, LINKS = parse_url(args)
    download_files(args)

start()

['https://cdn8.git.ir/1397/10/Packtpub%20Angular%20Full%20App%20with%20Angular%20Material%20Angularfire%20and%20NgRx%20%5BVideo%5D_git.ir.part1.rar\n',
 'https://cdn8.git.ir/1397/10/Packtpub%20Angular%20Full%20App%20with%20Angular%20Material%20Angularfire%20and%20NgRx%20%5BVideo%5D_git.ir.part2.rar\n',
 'https://cdn8.git.ir/1397/10/Packtpub%20Angular%20Full%20App%20with%20Angular%20Material%20Angularfire%20and%20NgRx%20%5BVideo%5D_git.ir.part3.rar']



""" Package setup. """
import setuptools


with open("README.md", "r") as f:
    long_description = f.read()

requirements = [
    "beautifulsoup4",
    "halo",
    "requests",
    "tqdm"
]

# Development Requirements
requirements_dev = ["pytest<=4.*", "black<=19.10b0"]

setuptools.setup(
    name="gitir_download",
    version="0.0.1",
    author="Yankee Maharjan",
    author_email="yankee.exe@gmail.com",
    description="Download videos from scattered links of git.ir",
    license="MIT",
    packages = setuptools.find_packages(exclude=["dist", "build", "*.egg-info"]),
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=requirements,
    extras_require={"dev": requirements_dev},
    entry_points={"console_scripts": ["gid = gitir_downloader.main:start"]},
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
    ],
)
